@@ -4,6 +4,6 @@ use strict;
 use JSON::Create;
 my $bread = { 'curry' => -sin(9**9**9) };
 my $jcnfh = JSON::Create->new ();
+print $jcnfh->run ($bread), "\n";
 $jcnfh->non_finite_handler(sub { return 'null'; });
-my $jcout = $jcnfh->run ($bread);
-print "$jcout\n";
+print $jcnfh->run ($bread), "\n";
