@@ -2,6 +2,7 @@
 use warnings;
 use strict;
 use JSON::Create 'create_json';
-my $weirdstring = {weird => "\t\r\n\x00"};
+# An example string containing various things.
+my $weirdstring = {weird => "\t\r\n\x00 " . '"' . '\\' . '/' };
 print create_json ($weirdstring);
 
